Improve this doc View Source

NOTE: This function is also published on window for easy access.

This function registers a module configuration code. It collects the configuration information which will be used when the injector is created by inject.

See inject for usage example

## Usage

`angular.mock.module(fns);`

### Arguments

Param | Type | Details
--- | --- | ---
fns | stringfunction()Object | any number of modules which are represented as string aliases or as anonymous module initialization functions. The modules are used to configure the injector. The 'ng' and 'ngMock' modules are automatically loaded. If an object literal is passed they will be registered as values in the module, the key being the module name and the value being what is returned.